@@ -213,7 +213,7 @@ class Module(JSON_Object):
             if flavor.id not in [iflavor.id for iflavor in self.flavors] or flavor.deactivated:
                 self.flavors.append(flavor)
             else:
-                RESOURCES.warn('Duplicated flavor for module %s: %s' % (self.id, flavor.id))
+                RESOURCES.warning('Duplicated flavor for module %s: %s', self.id, flavor.id)
 
     def merge_flavors(self, other_flavors):
         for other_flavor in other_flavors:
@@ -221,7 +221,7 @@ class Module(JSON_Object):
                 self_flavor = [iflavor for iflavor in self.flavors if iflavor.id == other_flavor.id][0]  # noqa: RUF015
                 self_flavor.merge(other_flavor)
             except IndexError:  # add if other_flavor does not exist
-                RESOURCES.debug('Add flavor: %s' % other_flavor.name)
+                RESOURCES.debug('Add flavor: %s', other_flavor.name)
                 self.flavors.append(other_flavor)
 
     def merge(self, other):
@@ -288,7 +288,7 @@ class XML_Definition(ET.ElementTree):
         try:
             return float(self.root.get('priority', -1))
         except ValueError:
-            RESOURCES.warn('No valid number type for property "priority": %s' % self.root.get('priority'))
+            RESOURCES.warning('No valid number type for property "priority": %s', self.root.get('priority'))
         return None
 
     @property
@@ -316,7 +316,7 @@ class XML_Definition(ET.ElementTree):
             try:
                 priority = float(elem.get('priority', -1))
             except ValueError:
-                RESOURCES.warn('No valid number type for property "priority": %s' % elem.get('priority'))
+                RESOURCES.warning('No valid number type for property "priority": %s', elem.get('priority'))
             categories = [cat.get('name') for cat in elem.findall('categories/category')]
             # a empty <categories/> causes the module to be hidden! while a not existing <category> element causes that the categories from the module are used
             hidden = elem.find('categories') is not None and not categories
@@ -413,16 +413,16 @@ class Manager(dict):
                 continue
             try:
                 parsed_xml = ET.parse(os.path.join(Manager.DIRECTORY, filename))  # noqa: S314
-                RESOURCES.debug('Loaded module %s' % filename)
+                RESOURCES.debug('Loaded module %s', filename)
                 for mod_tree in parsed_xml.getroot():
                     mod = XML_Definition(root=mod_tree)
                     if mod.deactivated:
-                        RESOURCES.info('Module is deactivated: %s' % filename)
+                        RESOURCES.info('Module is deactivated: %s', filename)
                         continue
                     # save list of definitions
                     modules.setdefault(mod.id, []).append(mod)
             except (xml.parsers.expat.ExpatError, ET.ParseError) as exc:
-                RESOURCES.warn('Failed to load module %s: %s' % (filename, exc))
+                RESOURCES.warning('Failed to load module %s: %s', filename, exc)
                 continue
         self.clear()
         self.update(modules)
@@ -459,14 +459,14 @@ class Manager(dict):
             mod = self.get_module(module_id)
 
             if ucr.is_true('umc/module/%s/disabled' % (module_id)):
-                RESOURCES.info('module %s is deactivated by UCR' % (module_id))
+                RESOURCES.info('module %s is deactivated by UCR', module_id)
                 continue
 
             if isinstance(mod, Link):
                 if mod.url:
                     modules[module_id] = mod
                 else:
-                    RESOURCES.info('invalid link %s: no url element' % (module_id))
+                    RESOURCES.info('invalid link %s: no url element', module_id)
                 continue
 
             if not mod.flavors:
@@ -477,11 +477,11 @@ class Manager(dict):
             deactivated_flavors = set()
             for flavor in flavors:
                 if ucr.is_true('umc/module/%s/%s/disabled' % (module_id, flavor.id)):
-                    RESOURCES.info('flavor %s (module=%s) is deactivated by UCR' % (flavor.id, module_id))
+                    RESOURCES.info('flavor %s (module=%s) is deactivated by UCR', flavor.id, module_id)
                     # flavor is deactivated by UCR variable
                     flavor.deactivated = True
 
-                RESOURCES.debug('mod=%r flavor=%r deactivated=%r hidden=%r' % (module_id, flavor.id, flavor.deactivated, flavor.hidden))
+                RESOURCES.debug('mod=%r flavor=%r deactivated=%r hidden=%r', module_id, flavor.id, flavor.deactivated, flavor.hidden)
                 if flavor.deactivated:
                     deactivated_flavors.add(flavor.id)
                     continue
@@ -524,14 +524,14 @@ class Manager(dict):
         permitted_commands) for the given command. If found, the id of
         the module is returned, otherwise None
         """
-        RESOURCES.info('Searching for module providing command %s' % command)
+        RESOURCES.info('Searching for module providing command %s', command)
         for module_id in modules:
             for cmd in modules[module_id].commands:
                 if cmd.name == command:
-                    RESOURCES.info('Found module %s' % module_id)
+                    RESOURCES.info('Found module %s', module_id)
                     return module_id
 
-        RESOURCES.info('No module provides %s' % command)
+        RESOURCES.info('No module provides %s', command)
         return None
 
 
