@@ -5,7 +5,6 @@
 #
 # SPDX-FileCopyrightText: 2012-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
-
 """
 Convenience decorators for developers of UMC modules
 ====================================================
@@ -27,15 +26,16 @@ UMC module development. You are not bound to use them if you need more
 flexibility.
 """
 
+from __future__ import annotations
+
 import functools
 import inspect
 import sys
 import time
 import traceback
 import types
-from collections.abc import Callable  # noqa: F401
 from threading import Lock, Thread
-from typing import TypeVar
+from typing import TYPE_CHECKING, TypeVar
 
 import tornado
 
@@ -47,6 +47,10 @@ from univention.management.console.modules.sanitizers import (
 )
 
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
+
 _ = Translation('univention.management.console').translate
 
 _T = TypeVar("_T")  # noqa: PYI018
@@ -75,57 +79,57 @@ def sanitize(*args, **kwargs):
     corresponding module or you define one yourself, deriving it from
     :class:`~univention.management.console.modules.sanitizers.Sanitizer`::
 
-            class SplitPathSanitizer(Sanitizer):
-                    def __init__(self):
-                            super(SplitPathSanitizer, self).__init__(
-                                    validate_none=True,
-                                    may_change_value=True)
+        class SplitPathSanitizer(Sanitizer):
+            def __init__(self):
+                super(SplitPathSanitizer, self).__init__(
+                    validate_none=True,
+                    may_change_value=True)
 
-                    def _sanitize(self, value, name, further_fields):
-                            if value is None:
-                                    return []
-                            try:
-                                    return value.split('/')
-                            except BaseException:
-                                    self.raise_validation_error('Split failed')
+            def _sanitize(self, value, name, further_fields):
+                if value is None:
+                    return []
+                try:
+                    return value.split('/')
+                except BaseException:
+                    self.raise_validation_error('Split failed')
 
     Before::
 
-            def my_func(self, request):
-                    var1 = request.options.get('var1')
-                    var2 = request.options.get('var2', 20)
-                    try:
-                            var1 = int(var1)
-                            var2 = int(var2)
-                    except (ValueError, TypeError):
-                            self.finished(request.id, None, 'Cannot convert to int', status=400)
-                            return
-                    if var2 < 10:
-                            self.finished(request.id, None, 'var2 must be >= 10', status=400)
-                            return
-                    self.finished(request.id, var1 + var2)
+        def my_func(self, request):
+            var1 = request.options.get('var1')
+            var2 = request.options.get('var2', 20)
+            try:
+                var1 = int(var1)
+                var2 = int(var2)
+            except (ValueError, TypeError):
+                self.finished(request.id, None, 'Cannot convert to int', status=400)
+                return
+            if var2 < 10:
+                self.finished(request.id, None, 'var2 must be >= 10', status=400)
+                return
+            self.finished(request.id, var1 + var2)
 
     After::
 
-            @sanitize(
-                    var1=IntegerSanitizer(required=True),
-                    var2=IntegerSanitizer(required=True, minimum=10, default=20)
-            )
-            def add(self, request):
-                    var1 = request.options.get('var1')  # could now use ['var1']
-                    var2 = request.options.get('var2')
-                    self.finished(request.id, var1 + var2)
+        @sanitize(
+            var1=IntegerSanitizer(required=True),
+            var2=IntegerSanitizer(required=True, minimum=10, default=20)
+        )
+        def add(self, request):
+            var1 = request.options.get('var1')  # could now use ['var1']
+            var2 = request.options.get('var2')
+            self.finished(request.id, var1 + var2)
 
     The decorator can be combined with other decorators like
     :func:`simple_response` (be careful with ordering of decorators here)::
 
-            @sanitize(
-                    var1=IntegerSanitizer(required=True),
-                    var2=IntegerSanitizer(required=True, minimum=10)
-            )
-            @simple_response
-            def add(self, var1, var2):
-                    return var1 + var2
+        @sanitize(
+            var1=IntegerSanitizer(required=True),
+            var2=IntegerSanitizer(required=True, minimum=10)
+        )
+        @simple_response
+        def add(self, var1, var2):
+            return var1 + var2
 
     Note that you lose the capability of specifying defaults in
     *@simple_response*. You need to do it in *@sanitize* now.
@@ -200,19 +204,17 @@ class SimpleThread:
 
     running_threads = 0
 
-    def __init__(self, name, function, callback):
-        # type: (str, Callable[..., _T], Callable[[SimpleThread, Union[BaseException, None, _T]], None]) -> None
+    def __init__(self, name: str, function: Callable[..., _T], callback: Callable[[SimpleThread, BaseException | _T | None], None]) -> None:
         self._name = name
         self._function = function
         self._callback = callback
-        self._result = None  # type: Union[BaseException, _T, None]
-        self._trace = None  # type: Optional[List[str]]
-        self._exc_info = None  # type: Optional[Tuple[Optional[Type[BaseException]], Optional[BaseException], None]]
+        self._result: BaseException | _T | None = None
+        self._trace: list[str] | None = None
+        self._exc_info: tuple[type[BaseException] | None, BaseException | None, None] | None = None
         self._finished = False
         self._lock = Lock()
 
-    def run(self, *args, **kwargs):
-        # type: (Optional[Tuple], Optional[Dict]) -> None
+    def run(self, *args: tuple | None, **kwargs: dict | None) -> None:
         """Starts the thread"""
         with self._lock:
             SimpleThread.running_threads += 1
@@ -221,17 +223,16 @@ class SimpleThread:
         future = io_loop.run_in_executor(None, self._run, *args, **kwargs)
         io_loop.add_future(future, lambda f: self.announce())
 
-    def _run(self, *args, **kwargs):
-        # type: (Optional[Tuple], Optional[Dict]) -> None
+    def _run(self, *args: tuple | None, **kwargs: dict | None) -> None:
         """
         Encapsulates the given thread function to handle the return
         value in a thread-safe way and to catch exceptions raised from
         within it.
         """
         try:
-            result = self._function(*args, **kwargs)  # type: Union[BaseException, _T]
-            trace = None  # type: Optional[List[str]]
-            exc_info = None  # type: Optional[Tuple[Optional[Type[BaseException]], Optional[BaseException], None]]
+            result: BaseException | _T = self._function(*args, **kwargs)
+            trace: list[str] | None = None
+            exc_info: tuple[type[BaseException] | None, BaseException | None, None] | None = None
         except BaseException as exc:
             try:
                 etype, value, tb = sys.exc_info()
@@ -250,8 +251,7 @@ class SimpleThread:
             self.unlock()
 
     @property
-    def result(self):
-        # type: () -> Union[BaseException, _T, None]
+    def result(self) -> BaseException | _T | None:
         """
         Contains the result of the thread function or the exception
         that occurred during thread processing
@@ -259,8 +259,7 @@ class SimpleThread:
         return self._result
 
     @property
-    def trace(self):
-        # type: () -> Optional[List[str]]
+    def trace(self) -> list[str] | None:
         """
         Contains a formatted traceback of the occurred exception during
         thread processing. If no exception has been raised the value is None
@@ -268,8 +267,7 @@ class SimpleThread:
         return self._trace
 
     @property
-    def exc_info(self):
-        # type: () -> Optional[Tuple[Optional[Type[BaseException]], Optional[BaseException], None]]
+    def exc_info(self) -> tuple[type[BaseException] | None, BaseException | None, None] | None:
         """
         Contains information about the exception that has occurred
         during the execution of the thread. The value is the some as
@@ -279,31 +277,26 @@ class SimpleThread:
         return self._exc_info
 
     @property
-    def name(self):
-        # type: () -> str
+    def name(self) -> str:
         return self._name
 
     @property
-    def finished(self):
-        # type: () -> bool
+    def finished(self) -> bool:
         """
         If the thread is finished the property contains the value
         True else False.
         """
         return self._finished
 
-    def lock(self):
-        # type: () -> None
+    def lock(self) -> None:
         """Locks a thread local lock object"""
         self._lock.acquire()
 
-    def unlock(self):
-        # type: () -> None
+    def unlock(self) -> None:
         """Unlocks a thread local lock object"""
         self._lock.release()
 
-    def announce(self):
-        # type: () -> None
+    def announce(self) -> None:
         with self._lock:
             SimpleThread.running_threads -= 1
 
@@ -333,15 +326,15 @@ def simple_response(function=None, with_flavor=None, with_progress=False, with_r
 
     .. code-block :: python
 
-            def my_func(self, response): pass
+        def my_func(self, response): pass
 
     you now define a function with the variables you would expect in
     *request.options*. Default values are supported:
 
     .. code-block :: python
 
-            @simple_response
-            def my_func(self, var1, var2='default'): pass
+        @simple_response
+        def my_func(self, var1, var2='default'): pass
 
     The decorator extracts variables from *request.options*. If the
     variable is not found, it either returns a failure or sets it to a
@@ -350,8 +343,8 @@ def simple_response(function=None, with_flavor=None, with_progress=False, with_r
     If you need to get the flavor passed to the function you can do it
     like this::
 
-            @simple_response(with_flavor=True)
-            def my_func(self, flavor, var1, var2='default'): pass
+        @simple_response(with_flavor=True)
+        def my_func(self, flavor, var1, var2='default'): pass
 
     With *with_flavor* set, the flavor is extracted from the *request*.
     You can also set with_flavor='varname', in which case the variable
@@ -359,48 +352,48 @@ def simple_response(function=None, with_flavor=None, with_progress=False, with_r
     As with ordinary option arguments, you may specify a default value
     for flavor in the function definition::
 
-            @simple_response(with_flavor='module_flavor')
-            def my_func(self, flavor='this comes from request.options',
-                    module_flavor='this is the flavor (and its default value)'): pass
+        @simple_response(with_flavor='module_flavor')
+        def my_func(self, flavor='this comes from request.options',
+            module_flavor='this is the flavor (and its default value)'): pass
 
     Instead of stating at the end of your function
 
     .. code-block:: python
 
-            self.finished(request.id, some_value)
+        self.finished(request.id, some_value)
 
     you now just
 
     .. code-block:: python
 
-            return some_value
+        return some_value
 
     Before::
 
-            def my_func(self, request):
-                    variable1 = request.options.get('variable1')
-                    variable2 = request.options.get('variable2')
-                    flavor = request.flavor or 'default flavor'
-                    if variable1 is None:
-                            self.finished(request.id, None, message='variable1 is required', success=False)
-                            return
-                    if variable2 is None:
-                    variable2 = ''
-                    try:
-                            value = '%s_%s_%s' % (self._saved_dict[variable1], variable2, flavor)
-                    except KeyError:
-                            self.finished(request.id, None, message='Something went wrong', success=False, status=500)
-                            return
-                    self.finished(request.id, value)
+        def my_func(self, request):
+            variable1 = request.options.get('variable1')
+            variable2 = request.options.get('variable2')
+            flavor = request.flavor or 'default flavor'
+            if variable1 is None:
+                self.finished(request.id, None, message='variable1 is required', success=False)
+                return
+            if variable2 is None:
+            variable2 = ''
+            try:
+                value = '%s_%s_%s' % (self._saved_dict[variable1], variable2, flavor)
+            except KeyError:
+                self.finished(request.id, None, message='Something went wrong', success=False, status=500)
+                return
+            self.finished(request.id, value)
 
     After::
 
-            @simple_response(with_flavor=True)
-            def my_func(self, variable1, variable2='', flavor='default_flavor'):
-                    try:
-                            return '%s_%s_%s' % (self._saved_dict[variable1], variable2, flavor)
-                    except KeyError:
-                            raise UMC_Error('Something went wrong')
+        @simple_response(with_flavor=True)
+        def my_func(self, variable1, variable2='', flavor='default_flavor'):
+            try:
+                return '%s_%s_%s' % (self._saved_dict[variable1], variable2, flavor)
+            except KeyError:
+                raise UMC_Error('Something went wrong')
 
     '''
     if function is None:
@@ -478,20 +471,20 @@ def multi_response(function=None, with_flavor=None, single_values=False, progres
     You do not return a value, you yield them (and you are supposed to
     yield!)::
 
-            @multi_response
-            def my_multi_func(self, iterator, variable1, variable2=''):
-                    # here, variable1 and variable2 are yet to be initialised
-                    # i.e. variable1 and variable2 will be None!
-                    do_some_initial_stuff()
-                    try:
-                            for variable1, variable2 in iterator:
-                                    # now they are set
-                                    yield '%s_%s' % (self._saved_dict[variable1], variable2)
-                    except KeyError:
-                            raise UMC_Error('Something went wrong')
-                    else:
-                            # only when everything went right...
-                            do_some_cleanup_stuff()
+        @multi_response
+        def my_multi_func(self, iterator, variable1, variable2=''):
+            # here, variable1 and variable2 are yet to be initialised
+            # i.e. variable1 and variable2 will be None!
+            do_some_initial_stuff()
+            try:
+                for variable1, variable2 in iterator:
+                    # now they are set
+                    yield '%s_%s' % (self._saved_dict[variable1], variable2)
+            except KeyError:
+                raise UMC_Error('Something went wrong')
+            else:
+                # only when everything went right...
+                do_some_cleanup_stuff()
 
     The above code will send a list of answers to the client as soon as
     the function is finished (i.e. after *do_some_cleanup_stuff()*)
@@ -501,9 +494,9 @@ def multi_response(function=None, with_flavor=None, single_values=False, progres
     add a comma, otherwise Python will assign the first value a list
     of one element::
 
-            for var, in iterator:
-                    # now var is set correctly
-                    pass
+        for var, in iterator:
+            # now var is set correctly
+            pass
     """
     if function is None:
         return lambda f: multi_response(f, with_flavor, single_values, progress)
@@ -640,17 +633,17 @@ def log(function=None, sensitives=None, customs=None, single_values=False):
     Log decorator to be used with
     :func:`simple_response`::
 
-            @simple_response
-            @log
-            def my_func(self, var1, var2):
-                    return "%s__%s" % (var1, var2)
+        @simple_response
+        @log
+        def my_func(self, var1, var2):
+            return "%s__%s" % (var1, var2)
 
     The above example will write two lines into the logfile for the
     module (given that the UCR variable *umc/module/debug/level*
     is set to at least 3)::
 
-            <date>  MODULE      ( INFO    ) : my_func got: var1='value1', var2='value2'
-            <date>  MODULE      ( INFO    ) : my_func returned: 'value1__value2'
+        <date>     INFO [         -] my_func got: var1='value1', var2='value2'
+        <date>     INFO [         -] my_func returned: 'value1__value2'
 
     The variable names are ordered by appearance and hold the values that
     are actually going to be passed to the function (i.e. after they were
@@ -662,28 +655,28 @@ def log(function=None, sensitives=None, customs=None, single_values=False):
     :class:`~univention.management.console.modules.sanitizers.PatternSanitizer`
     )::
 
-            @sanitize(pattern=PatternSanitizer())
-            @simple_reponse
-            @log(sensitives=['password'], customs={'pattern':lambda x: x.pattern})
-            def count_ucr(self, username, password, pattern):
-                    return self._ucr_count(username, password, pattern)
+        @sanitize(pattern=PatternSanitizer())
+        @simple_reponse
+        @log(sensitives=['password'], customs={'pattern':lambda x: x.pattern})
+        def count_ucr(self, username, password, pattern):
+            return self._ucr_count(username, password, pattern)
 
     This results in something like::
 
-            <date>  MODULE      ( INFO    ) : count_ucr got: password='********', username='Administrator', pattern='.*'
-            <date>  MODULE      ( INFO    ) : count_ucr returned: 650
+        <date>     INFO [         -] count_ucr got: password='********', username='Administrator', pattern='.*'
+        <date>     INFO [         -] count_ucr returned: 650
 
     The decorator also works with :func:`multi_response`::
 
-            @multi_response
-            @log
-            def multi_my_func(self, var1, var2):
-                    return "%s__%s" % (var1, var2)
+        @multi_response
+        @log
+        def multi_my_func(self, var1, var2):
+            return "%s__%s" % (var1, var2)
 
     This results in something like::
 
-            <date>  MODULE      ( INFO    ) : multi_my_func got: [var1='value1', var2='value2'], [var1='value3', var2='value4']
-            <date>  MODULE      ( INFO    ) : multi_my_func returned: ['value1__value2', 'value3__value4']
+        <date>     INFO [         -] multi_my_func got: [var1='value1', var2='value2'], [var1='value3', var2='value4']
+        <date>     INFO [         -] multi_my_func returned: ['value1__value2', 'value3__value4']
     '''
     if function is None:
         return lambda f: log(f, sensitives, customs, single_values)
