@@ -36,7 +36,6 @@ import tornado
 import tornado.curl_httpclient
 import tornado.gen
 import tornado.httpclient
-import tornado.web
 from tornado.iostream import StreamClosedError
 from tornado.web import HTTPError
 
@@ -185,7 +184,7 @@ class ModuleProcess(_ModuleConnection):
         self.__process.set_exit_callback(callback)
 
     async def connect(self, connect_retries=0):
-        if os.path.exists(self.socket) and stat.S_ISSOCK(os.stat(self.socket).st_mode):
+        if os.path.exists(self.socket) and stat.S_ISSOCK(os.stat(self.socket).st_mode):  # noqa: ASYNC240
             return True
         elif connect_retries > 200:
             raise CouldNotConnect('timeout exceeded')
@@ -228,8 +227,7 @@ class ModuleProcess(_ModuleConnection):
 
         return uri
 
-    def stop(self):
-        # type: () -> None
+    def stop(self) -> None:
         CORE.process('ModuleProcess: stopping %r', self.pid())
         if self.__process:
             tornado.ioloop.IOLoop.current().add_callback(self.stop_process)
@@ -244,8 +242,7 @@ class ModuleProcess(_ModuleConnection):
         CORE.info('ModuleProcess: child stopped')
         self.__process = None
 
-    def _died(self, returncode):
-        # type: (int) -> None
+    def _died(self, returncode: int) -> None:
         pid = self.pid()
         CORE.process('ModuleProcess: child %d (%s) exited with %d%s', pid, self.name, returncode, self.str_returncode(returncode))
         if self._client and not self._client._closed:
@@ -265,8 +262,7 @@ class ModuleProcess(_ModuleConnection):
         except KeyError:
             return ''
 
-    def pid(self):
-        # type: () -> int
+    def pid(self) -> int:
         """Returns process ID of module process"""
         if self.__process is None:
             return 0
@@ -313,7 +309,7 @@ class ModuleProxy(_ModuleConnection):
         self.unix_socket = None
 
     async def connect(self, connect_retries=0):
-        return not self.unix_socket or os.path.exists(self.unix_socket)
+        return not self.unix_socket or os.path.exists(self.unix_socket)  # noqa: ASYNC240
 
     def request(self, method, uri, headers=None, body=None):
         return self.do_request(method, uri, headers, body, self.unix_socket)
@@ -374,6 +370,7 @@ class SessionInfo(Resource):
         if not session.user.authenticated:
             raise Unauthorized()
         info['username'] = session.user.username
+        info['user_dn'] = session.user.user_dn
         info['auth_type'] = session.get_umc_auth_type()
         info['remaining'] = int(session.session_end_time - monotonic())
         self.content_negotiation(info)
